ast\_toolbox.rewards.example\_av\_reward module
===============================================

.. automodule:: ast_toolbox.rewards.example_av_reward
   :members:
   :undoc-members:
   :show-inheritance:
